<?php

/*
 * User chooser module
 * Defines 'segments' of users with a hook
 * provides form widgets, validation and submission
 * provides function to determine if a user is in a segment
*/


/*
 * implements hook_uchoo_segments
 * returns an array suitable for the select widget, so it can be nested. This example here is fictional
 * each of these is a callback which takes an arg and returns an array of uids
 * and another callback 'in_'.CALLBACK which takes an arg and a uid and returns TRUE or FALSE
 */
function user_chooser_uchoo_segments() {
  //segment defines all active users
  $callbacks = array(
    t('User mail hosts') => array(//this is used for grouping in the select widget
      'user_chooser_segment_gmail' => 'gmail users',
    )
  );
  return $callbacks;
}

/*
 * Example callback
 * select active users
 * Args:
 * $query, a partially built query to the users table: select uid from users
 * $args, as passed from the form element #args
 * $string may be passed from the autocomplete widget
 * $limit - restrict results to this many
*/
function user_chooser_segment_gmail($query, $args = array(), $string = '', $limit = FALSE) {
  $query->condition('mail', '%gmail.com', 'LIKE');
}

/*
 * Example 'in_' callback
 * return whether the user is in the segment
 */
function in_user_chooser_segment_gmail($args, $uid) {
  return strpos(user_load($uid)->mail, '.gmail.com');
}

/*
 * example form element, showing defaults where appropriate
 */
function hook_form() {
  $form['fieldname'] = array(
    '#title' => t('Blah blah'),
    '#type' => 'user_chooser_few',// or user_chooser_many
    '#callback' => 'user_chooser_segment_gmail', //anything returned from hook_user_chooser_segments
    '#args' => array(), //array to be passed as first arg to the callback function
    '#multiple' => TRUE, //same as in select element
    '#exclude' => array(1), //these uids will be excluded from the segment
    '#allow_blocked' => FALSE, //refers to $user->status,
    '#multiple_fail_alert' => 1,//how to respond when one uid of several fails validation: values 0 no alert, 1 warning, 2 error
  );
  return $form;
}